"use strict";
const typescript_plugin_util_1 = require("typescript-plugin-util");
const ts_simple_ast_extra_1 = require("ts-simple-ast-extra");
const typescript_ast_util_1 = require("typescript-ast-util");
const input_ui_ipc_provider_1 = require("input-ui-ipc-provider");
const PLUGIN_NAME = 'input-ui-ipc-provider-test-typescript-plugin';
function getApplicableRefactors(fileName, positionOrRange, userPreferences) {
    let refactors = info.languageService.getApplicableRefactors(fileName, positionOrRange, userPreferences);
    if (!inputConsumerReady) {
        return refactors;
    }
    refactors.push({
        name: `${PLUGIN_NAME}-refactor`,
        description: `${PLUGIN_NAME}-description`,
        actions: [
            { name: `${PLUGIN_NAME}-action-inputText`, description: 'inputText' },
            { name: `${PLUGIN_NAME}-action-messageBox`, description: 'messageBox' },
            { name: `${PLUGIN_NAME}-action-selectText`, description: 'selectText' }
        ]
    });
    return refactors;
}
function getEditsForRefactor(fileName, formatOptions, positionOrRange, refactorName, actionName, userPreferences) {
    const refactors = info.languageService.getEditsForRefactor(fileName, formatOptions, positionOrRange, refactorName, actionName, userPreferences);
    if (!actionName.startsWith(PLUGIN_NAME) || !inputConsumerReady) {
        return refactors;
    }
    if (actionName === `${PLUGIN_NAME}-action-inputText`) {
        inputConsumer.inputText({ prompt: 'Please enter your name', placeHolder: 'John Doe' })
            .then(response => {
            printInFile(fileName, positionOrRange, `Thank you, ${response.answer}, have a nice day`);
        });
    }
    else if (actionName === `${PLUGIN_NAME}-action-messageBox`) {
        inputConsumer.messageBox({ message: 'Welcome to refactors' })
            .then(response => {
            printInFile(fileName, positionOrRange, response.answer ? 'user clicked OK' : 'user dismissed the dialog');
        });
    }
    else if (actionName === `${PLUGIN_NAME}-action-selectText`) {
        inputConsumer
            .inputText({
            prompt: 'Please enter [from, to] to select',
            placeHolder: '{"from": 2, "to": 23}',
            value: '{"from": 2, "to": 23}',
            validateInput: (input) => {
                try {
                    JSON.parse(input);
                    return Promise.resolve(undefined);
                }
                catch (error) {
                    return Promise.resolve('Please enter valid JSON');
                }
            }
        })
            .then(response => inputConsumer.selectText(JSON.parse(response.answer)))
            .then(response => printInFile(fileName, positionOrRange, `Text selected, can you see it ? `))
            .catch(ex => printInFile(fileName, positionOrRange, `ERROR parsing input json text ${ex}`));
    }
    return refactors;
}
function printInFile(fileName, positionOrRange, s) {
    const project = ts_simple_ast_extra_1.createSimpleASTProject(info.project);
    const sourceFile = project.getSourceFile(fileName);
    sourceFile.insertText(typescript_ast_util_1.positionOrRangeToNumber(positionOrRange), `/* ${s} */`);
    sourceFile.saveSync();
}
let info;
const pluginDefinition = {
    getApplicableRefactors, getEditsForRefactor
};
let log;
let inputConsumerReady = false;
let inputConsumer;
function initInputConsumer() {
    input_ui_ipc_provider_1.setLogger(log);
    inputConsumer = input_ui_ipc_provider_1.getInputConsumer();
    inputConsumer.askSupported().then(() => inputConsumerReady = true);
}
module.exports = typescript_plugin_util_1.getPluginCreate(pluginDefinition, (modules, anInfo) => {
    info = anInfo;
    log = (msg) => info.project.projectService.logger.info(`${PLUGIN_NAME} ${msg}`);
    log(`created`);
    initInputConsumer();
});
//# sourceMappingURL=index.js.map